Changelog
=========

1.1b4 (2018-10-03)
------------------

- Fix in javascript helper.
  [rodfersou]


1.1b3 (2018-10-03)
------------------

- Fix node package version.
  [rodfersou]


1.1b2 (2018-10-03)
------------------

- Use a callback to fine tune the configuration at javascript helper.
  [rodfersou]

- Review to add Sprite plugin just if necessary.
  [rodfersou]

- Review to add SCSS files just if necessary.
  [rodfersou]

- Use script async by default.
  [rodfersou]

- Fix library definition to work with Plone 5.
  [thet, rodfersou]
- Emit current package version in package.json configuration (closes `#40 <https://github.com/simplesconsultoria/sc.recipe.staticresources/issues/40>`_).
  [rodfersou]


1.1b1 (2018-09-28)
------------------

- Create a module to reuse configuration.
  [rodfersou]


1.0b1 (2018-08-24)
------------------

- Change template to use a package Known-Good-Set (KGS).
  [rodfersou]

- Update package versions.
  [rodfersou]


1.0a2 (2018-01-24)
------------------

- Review how HTML and CSS are processed (closes `#23 <https://github.com/simplesconsultoria/sc.recipe.staticresources/issues/23>`_).
  [rodfersou]

- Remove old scripts generated by this recipe after buildout run (closes `#21 <https://github.com/simplesconsultoria/sc.recipe.staticresources/issues/21>`_).
  [rodfersou]

- Rename script to debug instead of dev to avoid misunderstanding (closes `#22 <https://github.com/simplesconsultoria/sc.recipe.staticresources/issues/22>`_).
  [rodfersou]

- Fix webpack installation conflict (closes `#25 <https://github.com/simplesconsultoria/sc.recipe.staticresources/issues/25>`_).
  [rodfersou]

- Fix package license typo on template.
  [hvelarde]

- Run build command after update recipe (closes `#18 <https://github.com/simplesconsultoria/sc.recipe.staticresources/issues/18>`_).
  [rodfersou]

- Add an error log if directory parameter is invalid.
  [rodfersou]


1.0a1 (2017-11-21)
------------------

- Initial release.
